==> stack-2.9.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stack
version:              2.9.1
visibility:           public
id:                   stack-2.9.1-B0BohA4qxSRCe1EMzGfVGc
key:                  stack-2.9.1-B0BohA4qxSRCe1EMzGfVGc
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  5e5375c2d696164d2ab95cd6ff2b782e
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:       Path.Extended Stack.Types.Cache System.Uname
import-dirs:          /usr/lib/ghc-9.2.8/site-local/stack-2.9.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stack-2.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.1-B0BohA4qxSRCe1EMzGfVGc
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-2QGjkfeUzb9GAwOHYL9mgm
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.4-EPVjDSBhsFM2RMZf92XUfK array-0.5.4.0
    async-2.2.5-L1pFc6v09ikFDHHjgXlurp
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    bytestring-0.11.4.0 casa-client-0.0.1-1RhnS6OJv0F1Wh27XfZAqc
    casa-types-0.0.2-7arwvfRElSAASDnELpKc0g
    colour-2.3.6-IwE0zgnqjD2KAyPru21evK
    conduit-1.3.5-EymqpkTSnlOJQExfW4pA9Z
    conduit-extra-1.3.6-8TgsS1xmoqL1UZX0gIG7l containers-0.6.5.1
    crypton-0.34-8wHA6W5DE4sCu89hfEsb06
    crypton-conduit-0.2.3-4necj2jftKM2KhICsGElO0 deepseq-1.4.6.1
    directory-1.3.6.2 echo-0.1.4-IB003eFNZa56WFK7EojaDw
    exceptions-0.10.4 extra-1.7.14-jQJF8WyS7TA7SEILRSf4e
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filelock-0.1.1.7-2BIoYRv3CvbCZA3b1AJLJs filepath-1.4.2.2
    fsnotify-0.3.0.1-JAzHUA8Ly7tLPUfKceUUsz
    generic-deriving-1.14.5-ARz8mDMmMKHFc8osoqmoOm
    hackage-security-0.6.2.5-3A7sKi1NmGnDDWF8iaIjGq
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hi-file-parser-0.1.6.0-GwcDyaorvrA56LhR2tWQXS
    hpack-0.35.2-BajPkt507p3IHk02RZxT6a hpc-0.6.1.0
    http-client-0.7.15-CfCS6ksdsf15aPqpZ0VwYm
    http-client-tls-0.3.6.3-Ly2SIcVuwJBTAdkdfNBFA
    http-conduit-2.3.8.3-HvM18zJkB1SA79UbnkhYAs
    http-download-0.2.1.0-KNKr3qAbEsp81gmk9dywMv
    http-types-0.12.4-4Sw8MSrZ5ruAIbTrBQxmp0
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    mintty-0.1.4-1ccqgcbenZyLIMuLsZsfuB
    mono-traversable-1.0.17.0-BPdJyJJ5GV07GZDJEWOVb3 mtl-2.2.2
    mustache-2.4.2-DE09zZeVNZS5hhEjcIgPLa
    neat-interpolation-0.5.1.4-3kr24vZImVu9vGcsXPzvcs
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    open-browser-0.2.1.0-LMnUbYhcKGIIiI90wgVucl
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T
    pantry-0.5.7-2BrsLeUmHuE9EjJ2aIxZyW
    path-0.9.5-JjBRvFuPyJp4eQu56SO1c0
    path-io-1.8.1-FfkT9bjIxjGCspOzR67XKA
    persistent-2.14.5.1-FdAF3X0cRzqIB6b09gIfbF
    persistent-sqlite-2.13.1.0-KHlCH541H676tGPz7n4pnd pretty-1.1.3.6
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB process-1.6.16.0
    project-template-0.2.1.0-3QFKYGfBMOe47HPaPyogCm
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    retry-0.9.3.1-5Uf8Ull0a88GuTp65YsjjI
    rio-0.1.22.0-GuorDdiFfVqLlB6Dr6qJ5j
    rio-prettyprint-0.1.6.0-DJMLP22XfeV6zk9SwefVvU
    split-0.2.5-FikGR5xLeivE3fJUC4tXgQ stm-2.5.0.2
    streaming-commons-0.2.2.6-BQfvqMZbFmf4h46rjHDijz
    tar-0.5.1.1-LuHavtc4dd2CbXF9ulAH4q template-haskell-2.18.0.0
    temporary-1.3-ATBZpgmb4kkJvnIbOIhyK2 text-1.2.5.0
    text-metrics-0.3.2-93iMIbQPBN35hCBqCrlmVx
    th-reify-many-0.1.10-3zRUGjnwtjR6F2lieeg1ET time-1.11.1.1
    tls-1.8.0-LdQS2kGBL5QlA0Ec3PwKm transformers-0.5.6.2
    typed-process-0.2.11.1-LEP73JrChKL9DD74cE137j
    unicode-transforms-0.4.0.1-uW6lu7PKJuAxUJWnxjVkD unix-2.7.2.2
    unix-compat-0.7.1-CwgGVRU8UUx5rtCuKDNV67
    unliftio-0.2.25.0-INoatlssrBVAcEPI6HA5Cp
    unordered-containers-0.2.20-B4pxT3iF0jR7WvKg6foz6h
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    yaml-0.11.11.2-ISk38OIdLV8C97BLTuiSCn
    zip-archive-0.4.3.2-2i06UCdpLWQEV9FWmTCqfw
    zlib-0.6.3.0-CkkXEuYiaZzEYzgsgwtii4

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stack-2.9.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stack
version:              2.9.1
visibility:           public
id:                   stack-2.9.1-21Fje8BhNVnKpkaL4reP4C
key:                  stack-2.9.1-21Fje8BhNVnKpkaL4reP4C
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  13015c88e4d259fbdcdd6382d0eb1d36
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:       Path.Extended Stack.Types.Cache System.Uname
import-dirs:          /usr/lib/ghc-9.2.8/site-local/stack-2.9.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stack-2.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.1-21Fje8BhNVnKpkaL4reP4C
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-9cB9LJUUgPXJU8E7LnOs6Q
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.4-EPVjDSBhsFM2RMZf92XUfK array-0.5.4.0
    async-2.2.5-L1pFc6v09ikFDHHjgXlurp
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw
    bytestring-0.11.4.0 casa-client-0.0.1-8ysPKukOYU21lIPCuljW2V
    casa-types-0.0.2-Id8QT7dHwjP2otWCJcU3bc
    colour-2.3.6-IwE0zgnqjD2KAyPru21evK
    conduit-1.3.5-HJrPb2gizae6YrSJmqHmw4
    conduit-extra-1.3.6-4xJ03XEd1nC3LAiJCGfS4E containers-0.6.5.1
    crypton-0.34-8wHA6W5DE4sCu89hfEsb06
    crypton-conduit-0.2.3-GLjrHEm2hlVCe43a1OjXt deepseq-1.4.6.1
    directory-1.3.6.2 echo-0.1.4-IB003eFNZa56WFK7EojaDw
    exceptions-0.10.4 extra-1.7.14-DA6OxIljaar6G900XWMNnS
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filelock-0.1.1.7-2BIoYRv3CvbCZA3b1AJLJs filepath-1.4.2.2
    fsnotify-0.3.0.1-26iIHI0FIscHqB3DEvqeWq
    generic-deriving-1.14.5-ARz8mDMmMKHFc8osoqmoOm
    hackage-security-0.6.2.5-3FgQZQbzJ7eG011EUOVdo4
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hi-file-parser-0.1.6.0-LtS1tXAA4Ge1A8dCckPQna
    hpack-0.35.2-GQpL0493h2uAuLQFO3tbLo hpc-0.6.1.0
    http-client-0.7.15-AbY8EtzmvQH2EDTDLRn1aE
    http-client-tls-0.3.6.3-Fx1EGfWZ8bV5XeYZXaz07Q
    http-conduit-2.3.8.3-FHKEFI1htvQ2IgqoPxTHYO
    http-download-0.2.1.0-o4kTn3LML22wQfOkCNc3y
    http-types-0.12.4-KywvdcgYD9RAReIdCAotLp
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    mintty-0.1.4-1ccqgcbenZyLIMuLsZsfuB
    mono-traversable-1.0.17.0-HRiUOdySJBGCW2Dczs3N2e mtl-2.2.2
    mustache-2.4.2-DSducrqi2ax5ePoY5gaMF2
    neat-interpolation-0.5.1.4-6VzqvGbvWM5H9j4TdmElUF
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    open-browser-0.2.1.0-LMnUbYhcKGIIiI90wgVucl
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T
    pantry-0.5.7-1fiiBnagQNjBAcneZsxFYK
    path-0.9.5-HtAO4YyfjPVHKRem7Wh71g
    path-io-1.8.1-6gBTAytr47AB1f6Oaf4Htm
    persistent-2.14.5.1-KIxt9wiZXMzEZUzIxXAtff
    persistent-sqlite-2.13.1.0-9cw4actwV0F9IpqefJhwaS pretty-1.1.3.6
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB process-1.6.16.0
    project-template-0.2.1.0-5y5Inqrbp3m24Jv6s0KQ6E
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    retry-0.9.3.1-Hmg98VuIxYTJDRzNEPAg8s
    rio-0.1.22.0-9SHh4KUXXduLj3pOKm3847
    rio-prettyprint-0.1.6.0-4vqeT5AnpDUGJEA3siaSaM
    split-0.2.5-FikGR5xLeivE3fJUC4tXgQ stm-2.5.0.2
    streaming-commons-0.2.2.6-BQfvqMZbFmf4h46rjHDijz
    tar-0.5.1.1-LuHavtc4dd2CbXF9ulAH4q template-haskell-2.18.0.0
    temporary-1.3-ATBZpgmb4kkJvnIbOIhyK2 text-1.2.5.0
    text-metrics-0.3.2-93iMIbQPBN35hCBqCrlmVx
    th-reify-many-0.1.10-3zRUGjnwtjR6F2lieeg1ET time-1.11.1.1
    tls-1.8.0-LdQS2kGBL5QlA0Ec3PwKm transformers-0.5.6.2
    typed-process-0.2.11.1-LEP73JrChKL9DD74cE137j
    unicode-transforms-0.4.0.1-uW6lu7PKJuAxUJWnxjVkD unix-2.7.2.2
    unix-compat-0.7.1-2FYQoXFb6gOEjBkuyg6QB3
    unliftio-0.2.25.0-INoatlssrBVAcEPI6HA5Cp
    unordered-containers-0.2.20-51DmuLN2CgdLFo3pmQx1qE
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    yaml-0.11.11.2-6donc6tydebLeEV4WeWGii
    zip-archive-0.4.3.2-2i06UCdpLWQEV9FWmTCqfw
    zlib-0.6.3.0-CkkXEuYiaZzEYzgsgwtii4

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
